#[non_exhaustive]pub enum CancelInviteOutcome {
Sent(Box<InviteCancellation>),
FinalResponse {
invite: TransactionKey,
response: Response,
},
InviteTimeout {
invite: TransactionKey,
},
InviteTransportError {
invite: TransactionKey,
error: Option<Error>,
},
}Expand description
The result of asking to cancel one exact outgoing INVITE transaction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Sent(Box<InviteCancellation>)
The provisional-response precondition was met and one CANCEL transaction was created.
FinalResponse
A final INVITE response arrived before a CANCEL transaction was created.
Fields

invite: TransactionKeyThe INVITE transaction that produced the response.

response: ResponseThe final response that won the race.
InviteTimeout
The INVITE timed out before a provisional response admitted CANCEL.
Fields

invite: TransactionKeyThe INVITE transaction that timed out.
InviteTransportError
The INVITE transport failed before a provisional response admitted CANCEL.