pub async fn accept_loop(
listener: TcpListener,
incoming: Sender<(TcpStream, SocketAddr)>,
)Expand description
Accept connections on a listener, adding each to the pool.
Returns when the listener fails.
pub async fn accept_loop(
listener: TcpListener,
incoming: Sender<(TcpStream, SocketAddr)>,
)Accept connections on a listener, adding each to the pool.
Returns when the listener fails.